@@ -6,6 +6,8 @@ import logging
 import os
 import re
 import uuid
+import jsonpath_ng.ext as jsonpath
+
 from datetime import datetime, timezone
 from typing import Dict, Optional, List
 from copy import deepcopy
@@ -16,6 +18,7 @@ from cirrus.lib.logging import get_task_logger
 from cirrus.lib.transfer import get_s3_session
 from cirrus.lib.utils import get_path, property_match
 
+
 # envvars
 PAYLOAD_BUCKET = os.getenv('CIRRUS_PAYLOAD_BUCKET', None)
 PUBLISH_TOPIC_ARN = os.getenv('CIRRUS_PUBLISH_TOPIC_ARN', None)
@@ -125,8 +128,16 @@ class ProcessPayload(dict):
         )
         for process in next_processes:
             new = deepcopy(self)
+            del new['id']
             new['process'].pop(0)
             new['process'][0] = process
+            if 'chain_filter' in process:
+                jsonfilter = jsonpath.parse(
+                    f'$.features[?({process["chain_filter"]})]',
+                )
+                new['features'] = [
+                    match.value for match in jsonfilter.find(new)
+                ]
             yield new
 
     def update(self):
@@ -483,12 +494,14 @@ class ProcessPayloads(object):
             #if state in ['QUEUED', 'PROCESSING']:
             #    logger.info(f"Skipping {payload['id']}, in {state} state")
             #    continue
-            if state in ['FAILED', ''] or _replace:
+            if payload['id'] in payload_ids:
+                logger.warning(f"Dropping duplicated payload {payload['id']}")
+            elif state in ['FAILED', ''] or _replace:
                 payload_id = payload()
                 if payload_id is not None:
                     payload_ids.append(payload_id)
             else:
-                logger.info(f"Skipping, input already in {state} state")
+                logger.info(f"Skipping {payload['id']}, input already in {state} state")
                 continue
 
         return payload_ids
